==> dvdisaster_0.72.4.orig.tar.bz2: dvdisaster-0.72.4/documentation/en/privacy.php <==
<?php
# dvdisaster: German homepage translation
# Copyright (C) 2004-2012 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!-- Insert actual page content below -->

<b>Privacy statement for the web sites</b><p>

dvdisaster.com, &nbsp; 
dvdisaster.de, &nbsp;
dvdisaster.net, &nbsp;
dvdisaster.org

<p>

The dvdisaster project (<a href="imprint.php">see the imprint for representatives</a>)
is taking your privacy seriously. The following statement is an oddity required
by German law. It gives you an overview  about the kind and purpose of the 
data we are collecting:

<p>

<b>Log files</b> (data processed by our internet servers)<p>

Your visit of our internet sites is being logged. 
Our servers collect the following data:

<ul>
<li>the type and version of your web browser</li>
<li>the operating system being used</li>
<li>the web site from which you we directed to our internet site (if applicable)</li>
<li>the host name or IP address of the computer which made the access</li>
<li>the time and date of the server query</li>
<li>the file names of the visited pages.</li>
</ul>

This data is not used to identify the visitors of our web sites.
It will not be combined with other data sources. The data will be
deleted after a statistical analysis.

<p>

<b>Cookies</b><p>

This internet site does not use cookies.

<p>

<b>Links to other internet sites</b><p>

Our internet pages contain links to other internet sites.
The dvdisaster project has no control over their publishers,
and whether they follow our privacy policy.

<p>

<b>Further development of these internet pages</b><p>

Further development of these internet pages may require our privacy policy
to be changed. Please revisit this policy statement occasionally and watch for
change notices. 

<!-- do not change below -->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>

==> dvdisaster_0.79.3.orig.tar.bz2: dvdisaster-0.79.3/documentation/en/privacy.php <==
<?php
# dvdisaster: German homepage translation
# Copyright (C) 2004-2010 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!--- Insert actual page content below --->

<b>Privacy statement for the web sites</b><p>

dvdisaster.com, &nbsp; 
dvdisaster.de, &nbsp;
dvdisaster.net, &nbsp;
dvdisaster.org

<p>

The dvdisaster project (<a href="imprint.php">see the imprint for representatives</a>)
is taking your privacy seriously. The following statement is an oddity required
by German law. It gives you an overview  about the kind and purpose of the 
data we are collecting:

<p>

<b>Log files</b> (data processed by our internet servers)<p>

Your visit of our internet sites is being logged. 
Our servers collect the following data:

<ul>
<li>the type and version of your web browser</li>
<li>the operating system being used</li>
<li>the web site from which you we directed to our internet site (if applicable)</li>
<li>the host name or IP address of the computer which made the access</li>
<li>the time and date of the server query</li>
<li>the file names of the visited pages.</li>
</ul>

This data is not used to identify the visitors of our web sites.
It will not be combined with other data sources. The data will be
deleted after a statistical analysis.

<p>

<b>Cookies</b><p>

This internet site does not use cookies.

<p>

<b>Links to other internet sites</b><p>

Our internet pages contain links to other internet sites.
The dvdisaster project has no control over their publishers,
and whether they follow our privacy policy.

<p>

<b>Further development of these internet pages</b><p>

Further development of these internet pages may require our privacy policy
to be changed. Please revisit this policy statement occasionally and watch for
change notices. 

<!--- do not change below --->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>
